==> calamares-settings-solydxk_4.17%2Br13.tar.xz: source/ts/calamares-solydxk_fr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="fr" sourcelanguage="en_US">
<context>
    <name>show</name>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="40"/>
        <source>&lt;h3&gt;Thank you for choosing SolydXK&lt;/h3&gt;&lt;br /&gt;You&apos;ve chosen a Linux distribution that is:&lt;br /&gt;&lt;ul&gt;&lt;li&gt;Secure and stable&lt;/li&gt;&lt;li&gt;Fast and responsive&lt;/li&gt;&lt;li&gt;Desktop-ready&lt;/li&gt;&lt;/ul&gt;&lt;br /&gt;Enjoy this new release and thank you for choosing SolydXK.&lt;br /&gt;&lt;br /&gt;The installation takes 15-30 minutes, depending on your settings.</source>
        <translation>&lt;h3&gt;Merci d&apos;avoir choisi SolydXK&lt;/h3&gt;&lt;br /&gt;Vous avez choisi une distribution Linux qui est:&lt;br /&gt;&lt;ul&gt;&lt;li&gt;Sûre et stable&lt;/li&gt;&lt;li&gt;Rapide et réactive&lt;/li&gt;&lt;li&gt;Prête à l&apos;emploi&lt;/li&gt;&lt;/ul&gt;&lt;br /&gt;Profitez de cette nouvelle version et encore merci d&apos;avoir choisi SolydXK.&lt;br /&gt;&lt;br /&gt;L&apos;installation prend 15-30 minutes, selon votre configuration.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="61"/>
        <source>&lt;h3&gt;Standing on the shoulders of Giants&lt;/h3&gt;&lt;br /&gt;SolydXK is a Debian-based GNU/Linux distribution derived from and compatible with Debian.&lt;br /&gt;&lt;br /&gt;SolydXK uses either the lightweight Xfce desktop for SolydX or the highly configurable and stunningly appealing KDE desktop for SolydK.&lt;br /&gt;&lt;br /&gt;Our innovations, the rapid development of Debian and the huge Debian package selection make SolydXK one of the most attractive desktop operating systems available to home users.</source>
        <translation>&lt;h3&gt;Assis sur les épaules de Géants&lt;/h3&gt;&lt;br /&gt;SolydXK est une distribution GNU/Linux basée sur, dérivée de, et compatible avec Debian.&lt;br /&gt;&lt;br /&gt;SolydXK propose soit le bureau léger et modulaire Xfce pour SolydX, soit le bureau hautement configurable et particulièrement attractif KDE pour SolydK.&lt;br /&gt;&lt;br /&gt;Nos innovations, le développement rapide de Debian et son immense logithèque font de SolydXK un des systèmes d&apos;exploitations  les plus intéressants pour les utilisations personnelles.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="81"/>
        <source>&lt;h3&gt;Out of the box&lt;/h3&gt;&lt;br /&gt;Firefox, Thunderbird, and LibreOffice come pre-installed in SolydXK, so you can get started immediately with the desktop and the Internet.&lt;br /&gt;&lt;br /&gt;Unlike other Linux distributions SolydXK is also ready to play your music, internet videos and more.&lt;br /&gt;&lt;br /&gt;A wide variety of software can be installed with a click of the mouse.&lt;br /&gt;&lt;br /&gt;SolydXK is compatible with most popular file formats such as: docx, xlsx, doc, xls, pdf, zip, rar, mp3, mpg, and many more.</source>
        <translation>&lt;h3&gt;Prêt à l&apos;emploi&lt;/h3&gt;&lt;br /&gt;Firefox, Thunderbird, and LibreOffice sont pré-installés sur SolydXK afin que vous puissiez immédiatement débuter vos travaux bureautiques ou surfer sur internet.&lt;br /&gt;&lt;br /&gt;Contrairement à d&apos;autres distributions Linux, SolydXK est aussi prêt à l&apos;emploi pour jouer vos morceaux de musique, surfer sur internet, regarder vos vidéos et plus encore.&lt;br /&gt;&lt;br /&gt;Une grande variété de logiciels peut être installée d&apos;unh simple clic de souris.&lt;br /&gt;&lt;br /&gt;SolydXK est compatible avec les formats de fichiers les plus répandus tels que: docx, xlsx, doc, xls, pdf, zip, rar, mp3, mpg, et bien d&apos;autres encore.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="102"/>
        <source>&lt;h3&gt;Office tools are ready to use as soon as you install SolydXK&lt;/h3&gt;&lt;br /&gt;LibreOffice, a powerful office software suite, comes built into SolydXK.&lt;br /&gt;&lt;br /&gt;LibreOffice is very easy to learn and use.&lt;br /&gt;&lt;br /&gt;You can use it to create letters, presentations and spreadsheets, as well as diagrams and databases.&lt;br /&gt;&lt;br /&gt;LibreOffice uses the standard OpenDocument format and it works with documents from other popular office applications including WordPerfect and Microsoft Office.</source>
        <translation>&lt;h3&gt;Les outils bureautiques sont utilisables dès l&apos;installation de SolydXK&lt;/h3&gt;&lt;br /&gt;LibreOffice, une suite bureautique puissante, est pré-installée sur SolydXK.&lt;br /&gt;&lt;br /&gt;LibreOffice est très facile à maîtriser et à utiliser.&lt;br /&gt;&lt;br /&gt;Vous pouvez l&apos;utiliser pour créer vos courriers, vos présentations et feuilles de calcul ainsi que vos diagrammes et bases de données.&lt;br /&gt;&lt;br /&gt;LibreOffice utilise le format standard OpenDocument et est compatible avec d&apos;autres formats d&apos;applications bureautiques très répandues telles que WordPerfect et Microsoft Office.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="123"/>
        <source>&lt;h3&gt;An alternative to mainstream operating systems&lt;/h3&gt;&lt;br /&gt;SolydXK is easy to use, powerful and configurable.&lt;br /&gt;&lt;br /&gt;SolydXK is safe and stable. Unlike other operating systems, it is not prone to computer viruses or spyware, it does not suffer from disk fragmentation, and it has no registry that requires periodic cleaning.&lt;br /&gt;&lt;br /&gt;SolydXK can detect other operating systems and install itself beside them.You can choose which operating system to launch when you start the computer.</source>
        <translation>&lt;h3&gt;Une alternative aux systèmes d&apos;exploitation grand public&lt;/h3&gt;&lt;br /&gt;SolydXK est facile d&apos;emploi, puissant et configurable.&lt;br /&gt;&lt;br /&gt;SolydXK est sûr et stable. Contrairement à d&apos;autres sytèmes d&apos;exploitation, il n&apos;est pas vulnérable aux virus et aux spywares, il ne provoque pas de fragmentation de disque et n&apos;a pas de registre qui nécessite un nettoyage régulier.&lt;br /&gt;&lt;br /&gt;SolydXK détecte les autres systèmes d&apos;exploitation et peut être installé à leur côté. Vous pouvez ainsi choisir le système d&apos;exploitation à utiliser lors du démarrage de l&apos;ordinateur.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="143"/>
        <source>&lt;h3&gt;Safe updates&lt;/h3&gt;&lt;br /&gt;Some operating systems make updating your system harder than it really needs to be. SolydXK thinks upgrades should be quick and easy, and then get out of the way.&lt;br /&gt;&lt;br /&gt;The Update Manager sits discreetly in your system tray and lets you know when updates are available. You don&apos;t have to apply updates when you don&apos;t want to. The Update Manager won&apos;t pop up or annoy you in any way.&lt;br /&gt;&lt;br /&gt;All updated files are maintained and closely checked by trusted developers and maintainers.&lt;br /&gt;&lt;br /&gt;All files are stored in special secure repositories for your use.&lt;br /&gt;&lt;br /&gt;The security repository is synchronized daily.</source>
        <translation>&lt;h3&gt;Mises à jour de sécurité&lt;/h3&gt;&lt;br /&gt;La procédure de mise à jour est, sur certains systèmes, beaucoup plus difficile qu&apos;elle ne devrait l&apos;être. SolydXK pense que les mises à niveau devraient être rapides, faciles et se faire rapidement oublier.&lt;br /&gt;&lt;br /&gt;Le gestionnaire de mises à jour apparaît discrètement dans votre zone de notifications et vous avertit lorsque des mises à jour sont disponibles. Vous n&apos;êtes pas obligé de mettre à jour votre système si vous ne le souhaitez pas. Le gestionnnaire de mises à jour ne vous harcèlera en aucune manière.&lt;br /&gt;&lt;br /&gt;Tous les fichiers mis à jour sont gérés et soigneusement vérifiés par des développeurs et des techniciens de confiance.&lt;br /&gt;&lt;br /&gt;Tous les fichiers sont placés à votre intention dans des dépôts sécurisés spécifiques.&lt;br /&gt;&lt;br /&gt;Le dépôt &apos;sécurité&apos; est synchronisé tous les jours.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="165"/>
        <source>&lt;h3&gt;A great community&lt;/h3&gt;&lt;br /&gt;SolydXK users are happy to share their passion and enthusiasm and are eager to help. Don&apos;t hesitate to ask questions on the forums or to get involved in the community.&lt;br /&gt;&lt;br /&gt;Send us your feedback and tell us about your experience. We&apos;ll listen to your ideas and use them to further improve SolydXK.</source>
        <translation>&lt;h3&gt;Une communauté dynamique&lt;/h3&gt;&lt;br /&gt;Les utilisateurs de SolydXK sont habituellement heureux de partager leur passion et leur enthousiasme et sont désireux d&apos;aider. N&apos;hésitez pas à poser des questions sur les forums ou à vous investir dans la communauté.&lt;br /&gt;&lt;br /&gt;Donnez-nous vos impressions et faites-nous part de votre expérience. Nous vous écouterons afin d&apos;améliorer SolydXK.</translation>
    </message>
</context>
</TS>

==> calamares-settings-solydxk_4.27%2Br13.tar.xz: source/ts/calamares-solydxk_fr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="fr" sourcelanguage="en_US">
<context>
    <name>show</name>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="40"/>
        <source>&lt;h3&gt;Thank you for choosing SolydXK&lt;/h3&gt;&lt;br /&gt;You&apos;ve chosen a Linux distribution that is:&lt;br /&gt;&lt;ul&gt;&lt;li&gt;Secure and stable&lt;/li&gt;&lt;li&gt;Fast and responsive&lt;/li&gt;&lt;li&gt;Desktop-ready&lt;/li&gt;&lt;/ul&gt;&lt;br /&gt;Enjoy this new release and thank you for choosing SolydXK.&lt;br /&gt;&lt;br /&gt;The installation takes 15-30 minutes, depending on your settings.</source>
        <translation>&lt;h3&gt;Merci d&apos;avoir choisi SolydXK&lt;/h3&gt;&lt;br /&gt;Vous avez choisi une distribution Linux qui est:&lt;br /&gt;&lt;ul&gt;&lt;li&gt;Sûre et stable&lt;/li&gt;&lt;li&gt;Rapide et réactive&lt;/li&gt;&lt;li&gt;Prête à l&apos;emploi&lt;/li&gt;&lt;/ul&gt;&lt;br /&gt;Profitez de cette nouvelle version et encore merci d&apos;avoir choisi SolydXK.&lt;br /&gt;&lt;br /&gt;L&apos;installation prend 15-30 minutes, selon votre configuration.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="61"/>
        <source>&lt;h3&gt;Standing on the shoulders of Giants&lt;/h3&gt;&lt;br /&gt;SolydXK is a Debian-based GNU/Linux distribution derived from and compatible with Debian.&lt;br /&gt;&lt;br /&gt;SolydXK uses either the lightweight Xfce desktop for SolydX or the highly configurable and stunningly appealing KDE desktop for SolydK.&lt;br /&gt;&lt;br /&gt;Our innovations, the rapid development of Debian and the huge Debian package selection make SolydXK one of the most attractive desktop operating systems available to home users.</source>
        <translation>&lt;h3&gt;Assis sur les épaules de Géants&lt;/h3&gt;&lt;br /&gt;SolydXK est une distribution GNU/Linux basée sur, dérivée de, et compatible avec Debian.&lt;br /&gt;&lt;br /&gt;SolydXK propose soit le bureau léger et modulaire Xfce pour SolydX, soit le bureau hautement configurable et particulièrement attractif KDE pour SolydK.&lt;br /&gt;&lt;br /&gt;Nos innovations, le développement rapide de Debian et son immense logithèque font de SolydXK un des systèmes d&apos;exploitations  les plus intéressants pour les utilisations personnelles.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="81"/>
        <source>&lt;h3&gt;Out of the box&lt;/h3&gt;&lt;br /&gt;Firefox, Thunderbird, and LibreOffice come pre-installed in SolydXK, so you can get started immediately with the desktop and the Internet.&lt;br /&gt;&lt;br /&gt;Unlike other Linux distributions SolydXK is also ready to play your music, internet videos and more.&lt;br /&gt;&lt;br /&gt;A wide variety of software can be installed with a click of the mouse.&lt;br /&gt;&lt;br /&gt;SolydXK is compatible with most popular file formats such as: docx, xlsx, doc, xls, pdf, zip, rar, mp3, mpg, and many more.</source>
        <translation>&lt;h3&gt;Prêt à l&apos;emploi&lt;/h3&gt;&lt;br /&gt;Firefox, Thunderbird, and LibreOffice sont pré-installés sur SolydXK afin que vous puissiez immédiatement débuter vos travaux bureautiques ou surfer sur internet.&lt;br /&gt;&lt;br /&gt;Contrairement à d&apos;autres distributions Linux, SolydXK est aussi prêt à l&apos;emploi pour jouer vos morceaux de musique, surfer sur internet, regarder vos vidéos et plus encore.&lt;br /&gt;&lt;br /&gt;Une grande variété de logiciels peut être installée d&apos;unh simple clic de souris.&lt;br /&gt;&lt;br /&gt;SolydXK est compatible avec les formats de fichiers les plus répandus tels que: docx, xlsx, doc, xls, pdf, zip, rar, mp3, mpg, et bien d&apos;autres encore.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="102"/>
        <source>&lt;h3&gt;Office tools are ready to use as soon as you install SolydXK&lt;/h3&gt;&lt;br /&gt;LibreOffice, a powerful office software suite, comes built into SolydXK.&lt;br /&gt;&lt;br /&gt;LibreOffice is very easy to learn and use.&lt;br /&gt;&lt;br /&gt;You can use it to create letters, presentations and spreadsheets, as well as diagrams and databases.&lt;br /&gt;&lt;br /&gt;LibreOffice uses the standard OpenDocument format and it works with documents from other popular office applications including WordPerfect and Microsoft Office.</source>
        <translation>&lt;h3&gt;Les outils bureautiques sont utilisables dès l&apos;installation de SolydXK&lt;/h3&gt;&lt;br /&gt;LibreOffice, une suite bureautique puissante, est pré-installée sur SolydXK.&lt;br /&gt;&lt;br /&gt;LibreOffice est très facile à maîtriser et à utiliser.&lt;br /&gt;&lt;br /&gt;Vous pouvez l&apos;utiliser pour créer vos courriers, vos présentations et feuilles de calcul ainsi que vos diagrammes et bases de données.&lt;br /&gt;&lt;br /&gt;LibreOffice utilise le format standard OpenDocument et est compatible avec d&apos;autres formats d&apos;applications bureautiques très répandues telles que WordPerfect et Microsoft Office.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="123"/>
        <source>&lt;h3&gt;An alternative to mainstream operating systems&lt;/h3&gt;&lt;br /&gt;SolydXK is easy to use, powerful and configurable.&lt;br /&gt;&lt;br /&gt;SolydXK is safe and stable. Unlike other operating systems, it is not prone to computer viruses or spyware, it does not suffer from disk fragmentation, and it has no registry that requires periodic cleaning.</source>
        <translation>&lt;h3&gt;Une alternative aux systèmes d&apos;exploitation grand public&lt;/h3&gt;&lt;br /&gt;SolydXK est facile d&apos;emploi, puissant et configurable.&lt;br /&gt;&lt;br /&gt;SolydXK est sûr et stable. Contrairement à d&apos;autres sytèmes d&apos;exploitation, il n&apos;est pas vulnérable aux virus et aux spywares, il ne provoque pas de fragmentation de disque et n&apos;a pas de registre qui nécessite un nettoyage régulier.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="142"/>
        <source>&lt;h3&gt;Safe updates&lt;/h3&gt;&lt;br /&gt;Some operating systems make updating your system harder than it really needs to be. SolydXK thinks upgrades should be quick and easy, and then get out of the way.&lt;br /&gt;&lt;br /&gt;The Update Manager sits discreetly in your system tray and lets you know when updates are available. You don&apos;t have to apply updates when you don&apos;t want to. The Update Manager won&apos;t pop up or annoy you in any way.&lt;br /&gt;&lt;br /&gt;All updated files are maintained and closely checked by trusted developers and maintainers.&lt;br /&gt;&lt;br /&gt;All files are stored in special secure repositories for your use.&lt;br /&gt;&lt;br /&gt;The security repository is synchronized daily.</source>
        <translation>&lt;h3&gt;Mises à jour de sécurité&lt;/h3&gt;&lt;br /&gt;La procédure de mise à jour est, sur certains systèmes, beaucoup plus difficile qu&apos;elle ne devrait l&apos;être. SolydXK pense que les mises à niveau devraient être rapides, faciles et se faire rapidement oublier.&lt;br /&gt;&lt;br /&gt;Le gestionnaire de mises à jour apparaît discrètement dans votre zone de notifications et vous avertit lorsque des mises à jour sont disponibles. Vous n&apos;êtes pas obligé de mettre à jour votre système si vous ne le souhaitez pas. Le gestionnnaire de mises à jour ne vous harcèlera en aucune manière.&lt;br /&gt;&lt;br /&gt;Tous les fichiers mis à jour sont gérés et soigneusement vérifiés par des développeurs et des techniciens de confiance.&lt;br /&gt;&lt;br /&gt;Tous les fichiers sont placés à votre intention dans des dépôts sécurisés spécifiques.&lt;br /&gt;&lt;br /&gt;Le dépôt &apos;sécurité&apos; est synchronisé tous les jours.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="164"/>
        <source>&lt;h3&gt;A great community&lt;/h3&gt;&lt;br /&gt;SolydXK users are happy to share their passion and enthusiasm and are eager to help. Don&apos;t hesitate to ask questions on the forums or to get involved in the community.&lt;br /&gt;&lt;br /&gt;Send us your feedback and tell us about your experience. We&apos;ll listen to your ideas and use them to further improve SolydXK.</source>
        <translation>&lt;h3&gt;Une communauté dynamique&lt;/h3&gt;&lt;br /&gt;Les utilisateurs de SolydXK sont habituellement heureux de partager leur passion et leur enthousiasme et sont désireux d&apos;aider. N&apos;hésitez pas à poser des questions sur les forums ou à vous investir dans la communauté.&lt;br /&gt;&lt;br /&gt;Donnez-nous vos impressions et faites-nous part de votre expérience. Nous vous écouterons afin d&apos;améliorer SolydXK.</translation>
    </message>
</context>
</TS>
